@@ -5,6 +5,7 @@ from django_simple_news.models import NewsItem
 
 
 class NewsFeed(Feed):
+    link = ''
 
     def title(self):
         return u"%s" % Site.objects.get_current().name
@@ -12,13 +13,12 @@ class NewsFeed(Feed):
     def description(self):
         return u'Latest news from %s' % Site.objects.get_current().name
 
-    def link(self):
-        # return reverse('news-index')
-        return '/news/'
-
     def items(self):
         return NewsItem.on_site.published(5)
 
+    def item_description(self, obj):
+        return obj.snippet
+
     def item_pubdate(self, item):
         from datetime import datetime
         return datetime(item.date.year, item.date.month, item.date.day)
